# Table of Contents

- [updating-fact-sheet](<./updating-fact-sheet.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Updating a Fact Sheet (GraphQL)](<./Updating-a-Fact-Sheet-GraphQL.md>)
  - [Updating the Name and Description on a Fact Sheet](<./Updating-a-Fact-Sheet-GraphQL/Updating-the-Name-and-Description-on-a-Fact-Sheet.md>)
  - [Updating the Quality Seal on a Fact Sheet](<./Updating-a-Fact-Sheet-GraphQL/Updating-the-Quality-Seal-on-a-Fact-Sheet.md>)
  - [Updating the External ID on a Fact Sheet](<./Updating-a-Fact-Sheet-GraphQL/Updating-the-External-ID-on-a-Fact-Sheet.md>)
  - [Deleting the External ID from a Fact Sheet](<./Updating-a-Fact-Sheet-GraphQL/Deleting-the-External-ID-from-a-Fact-Sheet.md>)
  - [Updating the Lifecycle on a Fact Sheet](<./Updating-a-Fact-Sheet-GraphQL/Updating-the-Lifecycle-on-a-Fact-Sheet.md>)
  - [Archiving a Fact Sheet](<./Updating-a-Fact-Sheet-GraphQL/Archiving-a-Fact-Sheet.md>)
  - [Recovering an Archived Fact Sheet](<./Updating-a-Fact-Sheet-GraphQL/Recovering-an-Archived-Fact-Sheet.md>)
  - [Updating a Custom Attribute on a Fact Sheet](<./Updating-a-Fact-Sheet-GraphQL/Updating-a-Custom-Attribute-on-a-Fact-Sheet.md>)
  - [Updating an Attribute of the Multiple Select Type on a Fact Sheet](<./Updating-a-Fact-Sheet-GraphQL/Updating-an-Attribute-of-the-Multiple-Select-Type-on-a-Fact-Sheet.md>)
  - [Was this page helpful?](<./Updating-a-Fact-Sheet-GraphQL/Was-this-page-helpful.md>)
